@@ -9,14 +9,15 @@
 package Lemonldap::NG::Handler::Lib::ZimbraPreAuth;
 
 use strict;
+use URI::Escape;
 use Digest::HMAC_SHA1 qw(hmac_sha1_hex);
 
-our $VERSION = '2.0.6';
+our $VERSION = '2.0.7';
 
 # Overload main run method
 sub run {
-    my ( $class, $req ) = @_;
-    my $ret = $class->Lemonldap::NG::Handler::Main::run($req);
+    my ( $class, $req )     = @_;
+    my ( $ret,   $session ) = $class->Lemonldap::NG::Handler::Main::run($req);
 
     # Continue only if user is authorized
     return $ret unless ( $ret == $class->OK );
@@ -28,10 +29,16 @@ sub run {
     my $localConfig      = $class->localConfig;
     my $zimbraPreAuthKey = $localConfig->{zimbraPreAuthKey};
     my $zimbraAccountKey = $localConfig->{zimbraAccountKey} || 'uid';
-    my $zimbraBy         = $localConfig->{zimbraBy} || 'id';
-    my $zimbraUrl        = $localConfig->{zimbraUrl} || '/service/preauth';
+    my $zimbraBy         = $localConfig->{zimbraBy}         || 'id';
+    my $zimbraUrl        = $localConfig->{zimbraUrl}    || '/service/preauth';
     my $zimbraSsoUrl     = $localConfig->{zimbraSsoUrl} || '^/zimbrasso$';
-    my $timeout          = $localConfig->{'timeout'} || '0';
+    my $timeout          = $localConfig->{'timeout'}    || '0';
+
+    # Remove trailing white-spaces
+    $zimbraAccountKey =~ s/\s+$//;
+    $zimbraBy         =~ s/\s+$//;
+    $zimbraUrl        =~ s/\s+$//;
+    $zimbraSsoUrl     =~ s/\s+$//;
 
     # Display found values in debug mode
     $class->logger->debug("zimbraPreAuthKey: $zimbraPreAuthKey");
@@ -57,9 +64,8 @@ sub run {
         $zimbraBy, $timeout );
 
     # Header location
-    Lemonldap::NG::Handler::API->set_header_out( 'Location' => $zimbra_url );
+    $class->set_header_out( $req, 'Location' => $zimbra_url );
 
-    # Return $class->REDIRECT
     return $class->REDIRECT;
 }
 
